# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.custom_sandbox_data import CustomSandboxData


class TestCustomSandboxData(unittest.TestCase):
    """CustomSandboxData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomSandboxData:
        """Test CustomSandboxData
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CustomSandboxData`
        """
        model = CustomSandboxData()
        if include_optional:
            return CustomSandboxData(
                accounts = [
                    moneykit.models.custom_sandbox_account.CustomSandboxAccount(
                        account_type = '', 
                        name = '', 
                        account_number = '', 
                        routing_number = '', )
                    ],
                owners = [
                    moneykit.models.owner.Owner(
                        names = [
                            ''
                            ], 
                        addresses = [
                            moneykit.models.address.Address(
                                city = '', 
                                country = '', 
                                postal_code = '', 
                                region = '', 
                                street = '', 
                                primary = True, )
                            ], 
                        phone_numbers = [
                            moneykit.models.phone_number.PhoneNumber(
                                number = '', 
                                primary = True, 
                                type = null, )
                            ], 
                        emails = [
                            moneykit.models.email.Email(
                                address = '', 
                                primary = True, )
                            ], )
                    ]
            )
        else:
            return CustomSandboxData(
                accounts = [
                    moneykit.models.custom_sandbox_account.CustomSandboxAccount(
                        account_type = '', 
                        name = '', 
                        account_number = '', 
                        routing_number = '', )
                    ],
        )
        """

    def testCustomSandboxData(self):
        """Test CustomSandboxData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
