# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.account_response import AccountResponse


class TestAccountResponse(unittest.TestCase):
    """AccountResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountResponse:
        """Test AccountResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccountResponse`
        """
        model = AccountResponse()
        if include_optional:
            return AccountResponse(
                account_id = '',
                account_type = '',
                name = '',
                nickname = '',
                account_mask = '',
                balances = moneykit.models.account_balances.AccountBalances(
                    currency = '', 
                    available = 1.337, 
                    current = 1.337, 
                    limit = 1.337, 
                    balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                original_id = '',
                closed = True
            )
        else:
            return AccountResponse(
                account_id = '',
                account_type = '',
                name = '',
                balances = moneykit.models.account_balances.AccountBalances(
                    currency = '', 
                    available = 1.337, 
                    current = 1.337, 
                    limit = 1.337, 
                    balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testAccountResponse(self):
        """Test AccountResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
