# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transaction_import_data import TransactionImportData


class TestTransactionImportData(unittest.TestCase):
    """TransactionImportData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionImportData:
        """Test TransactionImportData
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionImportData`
        """
        model = TransactionImportData()
        if include_optional:
            return TransactionImportData(
                account_id = '',
                transaction_id = '',
                amount = '',
                var_date = None,
                description = '',
                type = ''
            )
        else:
            return TransactionImportData(
                account_id = '',
                amount = '',
                var_date = None,
        )
        """

    def testTransactionImportData(self):
        """Test TransactionImportData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
