# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.response401_get_accounts_links_id_accounts_get import (
    Response401GetAccountsLinksIdAccountsGet,
)


class TestResponse401GetAccountsLinksIdAccountsGet(unittest.TestCase):
    """Response401GetAccountsLinksIdAccountsGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> Response401GetAccountsLinksIdAccountsGet:
        """Test Response401GetAccountsLinksIdAccountsGet
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Response401GetAccountsLinksIdAccountsGet`
        """
        model = Response401GetAccountsLinksIdAccountsGet()
        if include_optional:
            return Response401GetAccountsLinksIdAccountsGet(
                error_code = link_error.unauthorized_access,
                error_message = None,
                documentation_url = None
            )
        else:
            return Response401GetAccountsLinksIdAccountsGet(
                error_message = None,
        )
        """

    def testResponse401GetAccountsLinksIdAccountsGet(self):
        """Test Response401GetAccountsLinksIdAccountsGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
