# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
import re  # noqa: F401
from enum import Enum


try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class BudPrimaryCategory(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    BANKING = "banking"
    BORROWING_AND_LOANS = "borrowing_and_loans"
    CHARITY = "charity"
    DEPENDENT_COSTS = "dependent_costs"
    EDUCATION = "education"
    ENTERTAINMENT = "entertainment"
    EXPENSES = "expenses"
    FOOD_AND_DRINK = "food_and_drink"
    GAMBLING_AND_LOTTERIES = "gambling_and_lotteries"
    GENERAL = "general"
    HEALTH_AND_PERSONAL_CARE = "health_and_personal_care"
    HOME = "home"
    INCOME = "income"
    INSURANCE = "insurance"
    MEDIA_AND_TELECOMS = "media_and_telecoms"
    MORTGAGE_AND_RENT = "mortgage_and_rent"
    PENSIONS_SAVINGS_AND_INVESTMENTS = "pensions_savings_and_investments"
    SHOPPING = "shopping"
    TAXES = "taxes"
    TRANSFERS = "transfers"
    TRANSPORT = "transport"
    TRAVEL = "travel"
    UTILITIES = "utilities"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BudPrimaryCategory from a JSON string"""
        return cls(json.loads(json_str))
