# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.body import Body


class TestBody(unittest.TestCase):
    """Body unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Body:
        """Test Body
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Body`
        """
        model = Body()
        if include_optional:
            return Body(
                webhook_major_version = 1,
                webhook_minor_version = 0,
                webhook_idempotency_key = None,
                webhook_timestamp = None,
                link_id = None,
                link_tags = None,
                webhook_event = transactions.updates_available,
                state = 'pending',
                error = 'system_error',
                error_message = None,
                product = 'accounts',
                state_changed_at = None,
                has_history = None
            )
        else:
            return Body(
                webhook_idempotency_key = None,
                webhook_timestamp = None,
                link_id = None,
                link_tags = None,
                state = 'pending',
                product = 'accounts',
                state_changed_at = None,
        )
        """

    def testBody(self):
        """Test Body"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
