# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.create_access_token_response import CreateAccessTokenResponse


class TestCreateAccessTokenResponse(unittest.TestCase):
    """CreateAccessTokenResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateAccessTokenResponse:
        """Test CreateAccessTokenResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateAccessTokenResponse`
        """
        model = CreateAccessTokenResponse()
        if include_optional:
            return CreateAccessTokenResponse(
                access_token = '',
                token_type = '',
                expires_in = 56
            )
        else:
            return CreateAccessTokenResponse(
                access_token = '',
                token_type = '',
                expires_in = 56,
        )
        """

    def testCreateAccessTokenResponse(self):
        """Test CreateAccessTokenResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
