# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.create_link_session_request import CreateLinkSessionRequest


class TestCreateLinkSessionRequest(unittest.TestCase):
    """CreateLinkSessionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateLinkSessionRequest:
        """Test CreateLinkSessionRequest
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateLinkSessionRequest`
        """
        model = CreateLinkSessionRequest()
        if include_optional:
            return CreateLinkSessionRequest(
                settings = moneykit.models.link_session_setting_overrides.LinkSessionSettingOverrides(
                    providers = [
                        'moneykit'
                        ], 
                    products = null, 
                    countries = [
                        'US'
                        ], ),
                customer_user = moneykit.models.customer_user.CustomerUser(
                    id = '0123', 
                    email = null, 
                    phone = null, ),
                existing_link_id = '',
                institution_id = '',
                redirect_uri = '0',
                webhook = '0',
                link_tags = [
                    ''
                    ],
                connect_features = moneykit.models.money_kit_connect_features.MoneyKitConnectFeatures(
                    issue_reporter = True, 
                    enable_money_id = True, 
                    duplicate_institution_warning = True, 
                    duplicate_institution_rejected = True, 
                    connect_manually = True, 
                    permit_only_one_account = True, 
                    permit_only_depository_accounts = True, ),
                custom_sandbox_data = moneykit.models.custom_sandbox_data.CustomSandboxData(
                    accounts = [
                        moneykit.models.custom_sandbox_account.CustomSandboxAccount(
                            account_type = '', 
                            name = '', 
                            account_number = '', 
                            routing_number = '', )
                        ], 
                    owners = [
                        moneykit.models.owner.Owner(
                            names = [
                                ''
                                ], 
                            addresses = [
                                moneykit.models.address.Address(
                                    city = '', 
                                    country = '', 
                                    postal_code = '', 
                                    region = '', 
                                    street = '', 
                                    primary = True, )
                                ], 
                            phone_numbers = [
                                moneykit.models.phone_number.PhoneNumber(
                                    number = '', 
                                    primary = True, 
                                    type = null, )
                                ], 
                            emails = [
                                moneykit.models.email.Email(
                                    address = '', 
                                    primary = True, )
                                ], )
                        ], )
            )
        else:
            return CreateLinkSessionRequest(
                customer_user = moneykit.models.customer_user.CustomerUser(
                    id = '0123', 
                    email = null, 
                    phone = null, ),
                redirect_uri = '0',
        )
        """

    def testCreateLinkSessionRequest(self):
        """Test CreateLinkSessionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
