# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.get_links_response import GetLinksResponse


class TestGetLinksResponse(unittest.TestCase):
    """GetLinksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetLinksResponse:
        """Test GetLinksResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetLinksResponse`
        """
        model = GetLinksResponse()
        if include_optional:
            return GetLinksResponse(
                links = [
                    moneykit.models.get_links_link.GetLinksLink(
                        link_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                next_cursor = ''
            )
        else:
            return GetLinksResponse(
        )
        """

    def testGetLinksResponse(self):
        """Test GetLinksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
