# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.owner import Owner


class TestOwner(unittest.TestCase):
    """Owner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Owner:
        """Test Owner
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Owner`
        """
        model = Owner()
        if include_optional:
            return Owner(
                names = [
                    ''
                    ],
                addresses = [
                    moneykit.models.address.Address(
                        city = '', 
                        country = '', 
                        postal_code = '', 
                        region = '', 
                        street = '', 
                        primary = True, )
                    ],
                phone_numbers = [
                    moneykit.models.phone_number.PhoneNumber(
                        number = '', 
                        primary = True, 
                        type = null, )
                    ],
                emails = [
                    moneykit.models.email.Email(
                        address = '', 
                        primary = True, )
                    ]
            )
        else:
            return Owner(
                names = [
                    ''
                    ],
                addresses = [
                    moneykit.models.address.Address(
                        city = '', 
                        country = '', 
                        postal_code = '', 
                        region = '', 
                        street = '', 
                        primary = True, )
                    ],
                phone_numbers = [
                    moneykit.models.phone_number.PhoneNumber(
                        number = '', 
                        primary = True, 
                        type = null, )
                    ],
                emails = [
                    moneykit.models.email.Email(
                        address = '', 
                        primary = True, )
                    ],
        )
        """

    def testOwner(self):
        """Test Owner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
