# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.get_user_links_response import GetUserLinksResponse


class TestGetUserLinksResponse(unittest.TestCase):
    """GetUserLinksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetUserLinksResponse:
        """Test GetUserLinksResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetUserLinksResponse`
        """
        model = GetUserLinksResponse()
        if include_optional:
            return GetUserLinksResponse(
                links = {
                    'key' : moneykit.models.link_common.LinkCommon(
                        link_id = '', 
                        institution_id = '', 
                        institution_name = '', 
                        institution_avatar = '', 
                        state = null, 
                        error_code = null, 
                        last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        provider = null, 
                        link_tags = [
                            ''
                            ], 
                        tags = [
                            ''
                            ], 
                        webhook = '', 
                        products = null, 
                        available_products = [
                            'accounts'
                            ], )
                    }
            )
        else:
            return GetUserLinksResponse(
                links = {
                    'key' : moneykit.models.link_common.LinkCommon(
                        link_id = '', 
                        institution_id = '', 
                        institution_name = '', 
                        institution_avatar = '', 
                        state = null, 
                        error_code = null, 
                        last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        provider = null, 
                        link_tags = [
                            ''
                            ], 
                        tags = [
                            ''
                            ], 
                        webhook = '', 
                        products = null, 
                        available_products = [
                            'accounts'
                            ], )
                    },
        )
        """

    def testGetUserLinksResponse(self):
        """Test GetUserLinksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
