# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.account_numbers_legacy20230218 import AccountNumbersLegacy20230218


class TestAccountNumbersLegacy20230218(unittest.TestCase):
    """AccountNumbersLegacy20230218 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountNumbersLegacy20230218:
        """Test AccountNumbersLegacy20230218
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccountNumbersLegacy20230218`
        """
        model = AccountNumbersLegacy20230218()
        if include_optional:
            return AccountNumbersLegacy20230218(
                ach = [
                    moneykit.models.ach_number.AchNumber(
                        account_number = '', 
                        routing_number = '', 
                        wire_routing_number = '', )
                    ],
                eft = [
                    moneykit.models.eft_number.EftNumber(
                        account_number = '', 
                        institution_number = '', 
                        branch_number = '', )
                    ],
                bacs = [
                    moneykit.models.bacs_number.BacsNumber(
                        account_number = '', 
                        sort_code = '', )
                    ],
                international = [
                    moneykit.models.international_number.InternationalNumber(
                        iban = '', 
                        bic = '', )
                    ]
            )
        else:
            return AccountNumbersLegacy20230218(
                ach = [
                    moneykit.models.ach_number.AchNumber(
                        account_number = '', 
                        routing_number = '', 
                        wire_routing_number = '', )
                    ],
                eft = [
                    moneykit.models.eft_number.EftNumber(
                        account_number = '', 
                        institution_number = '', 
                        branch_number = '', )
                    ],
                bacs = [
                    moneykit.models.bacs_number.BacsNumber(
                        account_number = '', 
                        sort_code = '', )
                    ],
                international = [
                    moneykit.models.international_number.InternationalNumber(
                        iban = '', 
                        bic = '', )
                    ],
        )
        """

    def testAccountNumbersLegacy20230218(self):
        """Test AccountNumbersLegacy20230218"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
