# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.get_investment_transactions_response import (
    GetInvestmentTransactionsResponse,
)


class TestGetInvestmentTransactionsResponse(unittest.TestCase):
    """GetInvestmentTransactionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetInvestmentTransactionsResponse:
        """Test GetInvestmentTransactionsResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetInvestmentTransactionsResponse`
        """
        model = GetInvestmentTransactionsResponse()
        if include_optional:
            return GetInvestmentTransactionsResponse(
                total = 56,
                page = 56,
                size = 56,
                investment_transactions = [
                    moneykit.models.investment_transaction_response.InvestmentTransactionResponse(
                        investment_transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        type = '', 
                        fees = '', 
                        forex_rate = '', 
                        price = '', 
                        quantity = '', 
                        security_id = '', )
                    ],
                securities = [
                    moneykit.models.security_response.SecurityResponse(
                        security_id = '', 
                        name = '', 
                        type = '', 
                        currency = '', 
                        ticker = '', 
                        isin = '', 
                        sedol = '', 
                        close_price = '', 
                        close_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                    ],
                accounts = [
                    moneykit.models.account_response.AccountResponse(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], )
            )
        else:
            return GetInvestmentTransactionsResponse(
                total = 56,
                page = 56,
                size = 56,
                investment_transactions = [
                    moneykit.models.investment_transaction_response.InvestmentTransactionResponse(
                        investment_transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        type = '', 
                        fees = '', 
                        forex_rate = '', 
                        price = '', 
                        quantity = '', 
                        security_id = '', )
                    ],
                securities = [
                    moneykit.models.security_response.SecurityResponse(
                        security_id = '', 
                        name = '', 
                        type = '', 
                        currency = '', 
                        ticker = '', 
                        isin = '', 
                        sedol = '', 
                        close_price = '', 
                        close_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                    ],
                accounts = [
                    moneykit.models.account_response.AccountResponse(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], ),
        )
        """

    def testGetInvestmentTransactionsResponse(self):
        """Test GetInvestmentTransactionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
