# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.transactions_api import TransactionsApi


class TestTransactionsApi(unittest.TestCase):
    """TransactionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TransactionsApi()

    def tearDown(self) -> None:
        pass

    def test_correct_enrichment(self) -> None:
        """Test case for correct_enrichment

        /links/{id}/transactions/{txn_id}/enrichment
        """
        pass

    def test_get_transactions(self) -> None:
        """Test case for get_transactions

        /links/{id}/transactions
        """
        pass

    def test_get_transactions_sync(self) -> None:
        """Test case for get_transactions_sync

        /links/{id}/transactions/sync
        """
        pass

    def test_get_user_transactions(self) -> None:
        """Test case for get_user_transactions

        /users/{id}/transactions
        """
        pass


if __name__ == "__main__":
    unittest.main()
