# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.access_token_api import AccessTokenApi


class TestAccessTokenApi(unittest.TestCase):
    """AccessTokenApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessTokenApi()

    def tearDown(self) -> None:
        pass

    def test_create_access_token(self) -> None:
        """Test case for create_access_token

        /auth/token
        """
        pass

    def test_get_well_known_jwks(self) -> None:
        """Test case for get_well_known_jwks

        /.well-known/jwks.json
        """
        pass

    def test_instrospect_client(self) -> None:
        """Test case for instrospect_client

        /auth/introspect
        """
        pass


if __name__ == "__main__":
    unittest.main()
