# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.products_settings import ProductsSettings


class TestProductsSettings(unittest.TestCase):
    """ProductsSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProductsSettings:
        """Test ProductsSettings
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ProductsSettings`
        """
        model = ProductsSettings()
        if include_optional:
            return ProductsSettings(
                account_numbers = moneykit.models.product_settings.ProductSettings(
                    required = True, 
                    require_permission = True, 
                    prefetch = True, 
                    reason = '', ),
                identity = moneykit.models.product_settings.ProductSettings(
                    required = True, 
                    require_permission = True, 
                    prefetch = True, 
                    reason = '', ),
                transactions = moneykit.models.transactions_product_settings.TransactionsProductSettings(
                    required = True, 
                    require_permission = True, 
                    prefetch = True, 
                    reason = '', ),
                investments = moneykit.models.product_settings.ProductSettings(
                    required = True, 
                    require_permission = True, 
                    prefetch = True, 
                    reason = '', )
            )
        else:
            return ProductsSettings(
        )
        """

    def testProductsSettings(self):
        """Test ProductsSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
